==> ci-auto-update-phpboost-6.0.3.zip: phpboost_ynh/README_zh_Hans.md <==
<!--
注意：此 README 由 <https://github.com/YunoHost/apps/tree/master/tools/readme_generator> 自动生成
请勿手动编辑。
-->

# YunoHost 上的 PHPBoost

[![集成程度](https://dash.yunohost.org/integration/phpboost.svg)](https://dash.yunohost.org/appci/app/phpboost) ![工作状态](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![维护状态](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![使用 YunoHost 安装 PHPBoost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[阅读此 README 的其它语言版本。](./ALL_README.md)*

> *通过此软件包，您可以在 YunoHost 服务器上快速、简单地安装 PHPBoost。*  
> *如果您还没有 YunoHost，请参阅[指南](https://yunohost.org/install)了解如何安装它。*

## 概况

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**分发版本：** 6.0.3~ynh1

**演示：** <https://demo.phpboost.com/>

## 截图

![PHPBoost 的截图](./doc/screenshots/screenshot.png)

## 文档与资源

- 官方应用网站： <https://www.phpboost.com/>
- 官方管理文档： <https://www.phpboost.com/wiki/wiki.php>
- 上游应用代码库： <https://github.com/PHPBoost/PHPBoost>
- YunoHost 商店： <https://apps.yunohost.org/app/phpboost>
- 报告 bug： <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## 开发者信息

请向 [`testing` 分支](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing) 发送拉取请求。

如要尝试 `testing` 分支，请这样操作：

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
或
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**有关应用打包的更多信息：** <https://yunohost.org/packaging_apps>

==> ci-auto-update-phpboost-6.0.4.zip: phpboost_ynh/README_zh_Hans.md <==
<!--
注意：此 README 由 <https://github.com/YunoHost/apps/tree/master/tools/readme_generator> 自动生成
请勿手动编辑。
-->

# YunoHost 上的 PHPBoost

[![集成程度](https://dash.yunohost.org/integration/phpboost.svg)](https://ci-apps.yunohost.org/ci/apps/phpboost/) ![工作状态](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![维护状态](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![使用 YunoHost 安装 PHPBoost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[阅读此 README 的其它语言版本。](./ALL_README.md)*

> *通过此软件包，您可以在 YunoHost 服务器上快速、简单地安装 PHPBoost。*  
> *如果您还没有 YunoHost，请参阅[指南](https://yunohost.org/install)了解如何安装它。*

## 概况

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**分发版本：** phpboost-6.0.4~ynh1

**演示：** <https://demo.phpboost.com/>

## 截图

![PHPBoost 的截图](./doc/screenshots/screenshot.png)

## 文档与资源

- 官方应用网站： <https://www.phpboost.com/>
- 官方管理文档： <https://www.phpboost.com/wiki/wiki.php>
- 上游应用代码库： <https://github.com/PHPBoost/PHPBoost>
- YunoHost 商店： <https://apps.yunohost.org/app/phpboost>
- 报告 bug： <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## 开发者信息

请向 [`testing` 分支](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing) 发送拉取请求。

如要尝试 `testing` 分支，请这样操作：

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
或
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**有关应用打包的更多信息：** <https://yunohost.org/packaging_apps>
